[![Travis CI w/ Logo](https://img.shields.io/travis/grburgess/gbmgeometry/master.svg?logo=travis)](https://travis-ci.org/grburgess/gbmgeometry)  [![codecov](https://codecov.io/gh/grburgess/gbmgeometry/branch/master/graph/badge.svg)](https://codecov.io/gh/grburgess/gbmgeometry)
[![PyPi Downloads](http://pepy.tech/badge/gbmgeometry)](http://pepy.tech/project/gbmgeometry)
[![PyPI version fury.io](https://badge.fury.io/py/gbmgeometry.svg)](https://pypi.python.org/pypi/gbmgeometry/)

# gbmgeometry
Routines to handle GBM geometry and plotting 

## Requirements
* astropy
* numpy
* matplotlib
* scipy
* Basemap
* seaborn
* spherical_geometry

## Install

$> python setup.py install
